/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.client;

import org.apache.abdera.model.Document;
import org.apache.abdera.model.Entry;
import org.apache.abdera.model.Feed;
import org.apache.abdera.protocol.client.AbderaClient;
import org.apache.abdera.protocol.client.ClientResponse;
import org.wso2.registry.*;

import java.io.IOException;
import java.io.InputStream;
import java.util.Date;
import java.util.List;

public class RegistryClient implements Registry {

    public Resource get(String path) throws RegistryException {

        AbderaClient client = new AbderaClient();
        ClientResponse response = client.get(path);
        Document doc = response.getDocument();

        if (doc instanceof Feed) {

            Feed feed = (Feed) doc;

            Resource collection = new Resource();
            collection.setDirectory(true);

            List entries = feed.getEntries();
            String[] childPaths = new String[entries.size()];

            for (int i = 0; i < entries.size(); i++) {
                Entry entry = (Entry) entries.get(i);
                childPaths[i] = entry.getLink("edit").getHref().toString();
            }

            collection.setContent(childPaths);

            return collection;

        } else if (doc instanceof Entry) {

            Entry entry = (Entry) doc;

            Resource resource = new Resource();
            resource.setDirectory(false);
            resource.setAuthorUserName(entry.getAuthor().getName());

            String contentURL = entry.getLink("edit-media").getHref().toString();
            ClientResponse contentResponse = client.get(contentURL);

            try {
                InputStream contentInput = contentResponse.getInputStream();
                
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

        return null;
    }

    public boolean resourceExists(String path) throws RegistryException {
        return false;  //To change body of implemented methods use File | Settings | File Templates.
    }

    public void put(String path, Resource resource) throws RegistryException {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    public void delete(String path) throws RegistryException {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    public String[] getVersions(String path) throws RegistryException {
        return new String[0];  //To change body of implemented methods use File | Settings | File Templates.
    }

    public void restoreVersion(String versionPath) throws RegistryException {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    public void applyTag(String resourcePath, String tag) throws RegistryException {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    public TaggedResourcePath[] getResourcePathsWithTag(String tag) throws RegistryException {
        return new TaggedResourcePath[0];  //To change body of implemented methods use File | Settings | File Templates.
    }

    public Tag[] getTags(String resourcePath) throws RegistryException {
        return new Tag[0];  //To change body of implemented methods use File | Settings | File Templates.
    }

    public void addComment(String resourcePath, Comment comment) throws RegistryException {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    public Comment[] getComments(String resourcePath) throws RegistryException {
        return new Comment[0];  //To change body of implemented methods use File | Settings | File Templates.
    }

    public void rateResource(String resourcePath, int rating) throws RegistryException {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    public float getAverageRating(String resourcePath) throws RegistryException {
        return 0;  //To change body of implemented methods use File | Settings | File Templates.
    }

    public int getRating(String path, String userName) throws RegistryException {
        return 0;  //To change body of implemented methods use File | Settings | File Templates.
    }

    public Resource executeQuery(String path, Object[] parameters) throws RegistryException {
        return null;  //To change body of implemented methods use File | Settings | File Templates.
    }

    public LogEntry[] getLogs(String resourcePath, int action, String userName, Date from, Date to, boolean descending)
            throws RegistryException {
        return new LogEntry[0];  //To change body of implemented methods use File | Settings | File Templates.
    }

    public void removeTag(String path, String tag) throws RegistryException {
        //To change body of implemented methods use File | Settings | File Templates.
    }
}
